@@ -17,13 +17,17 @@ echo This script runs configure ...
 echo You did remember necessary arguments for configure, right?
 
 if test ! -x "`which aclocal`"
-then echo you need autoconfig to generate the Makefile
+then echo you need autoconf to generate the configure script
 fi
 
-libtoolize --force --copy
-# autoheader
-aclocal 
-# automake --add-missing --copy --gnu
-autoconf > /dev/null 2>&1
-./configure $*
 
+ACLOCALARG=""
+test -d /sw/share/ && ACLOCALARG=" -I /sw/share/aclocal"
+
+
+libtoolize --force --copy
+acinclude
+aclocal ${ACLOCALARG}
+autoconf
+
+./configure ${CFGARGS}  $*
